@@ -3,9 +3,9 @@ package github
 import (
 	"os"
 
-	"github.com/cloudskiff/driftctl/pkg/output"
-	"github.com/cloudskiff/driftctl/pkg/remote/terraform"
-	tf "github.com/cloudskiff/driftctl/pkg/terraform"
+	"github.com/snyk/driftctl/pkg/output"
+	"github.com/snyk/driftctl/pkg/remote/terraform"
+	tf "github.com/snyk/driftctl/pkg/terraform"
 )
 
 type GithubTerraformProvider struct {
